==> dde-daemon_5.14.58.orig.tar.xz: dde-daemon-5.14.58/misc/ts/com.deepin.daemon.Fprintd.policy/policy_kab.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="kab" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.fprintd.enroll!message" line="0"/>
			<source>Authentication is required to add fingerprint password</source>
			<translation>Asesteb yettusra i tmerna n wawal uffir n udsil umḍin</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.enroll!description" line="0"/>
			<source>Add fingerprint password</source>
			<translation>Rnu awal uffir n udsil umḍin</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!message" line="0"/>
			<source>Authentication is required to clear fingerprint passwords</source>
			<translation>Asesteb yettusra i tukksa n wawalen uffiren n udsil umḍin</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!description" line="0"/>
			<source>Clear fingerprint passwords</source>
			<translation>Sfeḍ wawalen uffiren n udsil umḍin</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!message" line="0"/>
			<source>Authentication is required to rename fingerprint password</source>
			<translation>Asesteb yettusra i ubeddel n yisem</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!description" line="0"/>
			<source>Rename fingerprint password</source>
			<translation>Beddl isem i wawal uffir n udsil umḍin</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!message" line="0"/>
			<source>Password is required to perform this action</source>
			<translation>Yettusra wawal uffir i uselken n tigawt-a</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!description" line="0"/>
			<source>Manage fingerprint passwords</source>
			<translation>Sefrek awalen uffiren n udsil umḍin</translation>
		</message>
	</context>
</TS>

==> dde-daemon_5.14.137.2.orig.tar.xz: dde-daemon-5.14.137.2/misc/ts/com.deepin.daemon.Fprintd.policy/policy_kab.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="kab" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.fprintd.enroll!message" line="0"/>
			<source>Authentication is required to add fingerprint password</source>
			<translation>Asesteb yettusra i tmerna n wawal uffir n udsil umḍin</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.enroll!description" line="0"/>
			<source>Add fingerprint password</source>
			<translation>Rnu awal uffir n udsil umḍin</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!message" line="0"/>
			<source>Authentication is required to clear fingerprint passwords</source>
			<translation>Asesteb yettusra i usfaḍ n wawalen uffiren n udsil umḍin</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!description" line="0"/>
			<source>Clear fingerprint passwords</source>
			<translation>Sfeḍ wawalen uffiren n udsil umḍin</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!message" line="0"/>
			<source>Authentication is required to rename fingerprint password</source>
			<translation>Asesteb yettusra i ubeddel n yisem</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!description" line="0"/>
			<source>Rename fingerprint password</source>
			<translation>Beddl isem i wawal uffir n udsil umḍin</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!message" line="0"/>
			<source>Password is required to perform this action</source>
			<translation>Yettusra wawal uffir i uselken n tigawt-a</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!description" line="0"/>
			<source>Manage fingerprint passwords</source>
			<translation>Sefrek awalen uffiren n udsil umḍin</translation>
		</message>
	</context>
</TS>
